===========
basestation
===========

A library to interface with the Valve Index® Base Stations (also commonly referred to as 'Lighthouse V2') through BLE.  
This lib mostly exists because homeasstant requires all code directly interfacing with hardware to be done through a seperate lib, but it can be used just fine as a standalone lib.

Features
===========

- Scan for nearby base stations.
- Power stations on/off
- Read power state
- Identify (make LED flash)

Description
===========

I will write a more extensive API doc when I have my homeassistant stuff going.
